@@ -9,7 +9,6 @@ use std::{
     net::{Ipv4Addr, Ipv6Addr, SocketAddr, SocketAddrV4, SocketAddrV6, ToSocketAddrs},
     slice,
     str::FromStr,
-    u8,
     vec,
 };
 
@@ -422,7 +421,7 @@ fn write_ipv6_address<B: BufMut>(addr: &SocketAddrV6, buf: &mut B) {
 }
 
 fn write_domain_name_address<B: BufMut>(dnaddr: &str, port: u16, buf: &mut B) {
-    assert!(dnaddr.len() <= u8::max_value() as usize);
+    assert!(dnaddr.len() <= u8::MAX as usize);
 
     buf.put_u8(consts::SOCKS5_ADDR_TYPE_DOMAIN_NAME);
     assert!(
@@ -659,7 +658,7 @@ impl HandshakeRequest {
     pub fn write_to_buf<B: BufMut>(&self, buf: &mut B) {
         let HandshakeRequest { ref methods } = *self;
         buf.put_slice(&[consts::SOCKS5_VERSION, methods.len() as u8]);
-        buf.put_slice(&methods);
+        buf.put_slice(methods);
     }
 
     /// Get length of bytes
